@@ -45,7 +45,7 @@ from autobahn.asyncio.websocket import WebSocketClientProtocol
 
 from .multipart import Data
 
-__version__ = "0.11.3"
+__version__ = "0.12"
 
 BASE_URL = "https://volafile.io"
 BASE_ROOM_URL = BASE_URL + "/r/"
@@ -708,6 +708,10 @@ class Room:
         if self.connected:
             self.conn.close()
 
+    def report(self):
+        """Reports this room to moderators"""
+        self.conn.make_call("submitReport", [{}])
+
     @property
     def title(self):
         """Gets the title name of the room (e.g. /g/entoomen)"""
